code2lang = {
    "af": "Afrikaans",
    "am": "Amharic",
    "ar": "Arabic",
    "bg": "Bulgarian",
    "bn": "Bengali",
    "bo": "Tibetan",
    "ca": "Catalan",
    "ckb": "Central Kurdish",
    "cs": "Czech",
    "cy": "Welsh",
    "da": "Dannish",
    "de": "German",
    "dv": "Divehi",
    "el": "Greek",
    "en": "English",
    "es": "Spanish",
    "et": "Estonian",
    "eu": "Basque",
    "fa": "Persian",
    "fi": "Finnish",
    "fr": "French",
    "gu": "Gujarati",
    "he": "Hebrew",
    "hi": "Hindi",
    "hi-Latn": "Hindi (latin)",
    "hr": "Croatian",
    "hu": "Hungarian",
    "ht": "Haitian",
    "hy": "Armenian",
    "id": "Indonesian",
    "it": "Italian",
    "is": "Icelandic",
    "ja": "Japanese",
    "ka": "Georgian",
    "km": "Central Khmer",
    "kn": "Kannada",
    "ko": "Korean",
    "lt": "Lithuanian",
    "lv": "Latvian",
    "lo": "Lao",
    "mk": "Macedonian",
    "ml": "Malayalam",
    "mr": "Marathi",
    "my": "Burmese",
    "ne": "Nepali",
    "nl": "Dutch",
    "no": "Norwegian",
    "or": "Oriya",
    "pa": "Punjabi",
    "pl": "Polish",
    "pt": "Portuguese",
    "ps": "Pashto",
    "ro": "Romanian",
    "ru": "Russian",
    "sd": "Sindhi",
    "si": "Sinhala",
    "sk": "Slovak",
    "sl": "Slovene",
    "so": "Somali",
    "sr": "Serbian",
    "sq": "Albanian",
    "sv": "Swedish",
    "sw": "Swahili",
    "ta": "Tamil",
    "te": "Telugu",
    "th": "Thai",
    "tl": "Tagalog",
    "tr": "Turkish",
    "ug": "Uighur",
    "uk": "Ukrainian",
    "ur": "Urdu",
    "vi": "Vietnamese",
    "zh": "Chinese",
    "zh-cn": "Simplified Chinese",
    "zh-tw": "Traditional Chinese",
}

lang2code = {lang: code for code, lang in code2lang.items()}
